diff --git a/frontend/www/contentcomments.html b/frontend/www/contentcomments.html
index 72fd2112c5885a729dfe36eef697fd7899f68e36..6871cbe0dcdb443a113c88c688379324f87d66c2 100644
--- a/frontend/www/contentcomments.html
+++ b/frontend/www/contentcomments.html
@@ -20,7 +20,7 @@
                 <p>Here you can post comments and like.</p>
         </div>
         <div class="col-lg-6">
-            <input type="button" class="btn btn-primary" id="btn-like" value="Like">
+            <input type="button" class="btn btn-success" id="btn-like" value="Like">
         </div>
         <div class="col-lg-6">
 
diff --git a/frontend/www/scripts/addcontent.js b/frontend/www/scripts/addcontent.js
index 06f338e2a88b3f73433ccdb92de95f79d1edee9b..e1e79ab69b37b6f3283df1a99a121b97de14a6cb 100644
--- a/frontend/www/scripts/addcontent.js
+++ b/frontend/www/scripts/addcontent.js
@@ -6,8 +6,8 @@ function handleCancelButtonDuringCreate() {
 }
 
 /**
  * This api request is fired when the user clicks the button to create a group
  * It sends a POST request with the form data, and relocates to groups.html or
  * sends an error message in respons. 
  */
 async function addContent() {
@@ -25,7 +25,7 @@ async function addContent() {
         let response = await sendRequest("POST", `${HOST}/api/content/`, body);
 
         if (response.ok) {
-            window.location.replace("groups.html");
+            window.location.replace(`groupContent.html?id=${groupId}`);
         } else {
             let data = await response.json();
             let alert = createAlert("Could not create new group!", data);
@@ -6,8 +6,8 @@ function handleCancelButtonDuringCreate() {
 
 /**
- * This api request is fired when the user clicks the button to create a group
- * It sends a POST request with the form data, and relocates to groups.html or
+ * This api request is fired when the user clicks the button to add content to a group
+ * It sends a POST request with the form data, and relocates to groupsContent page or
  * sends an error message in respons. 
  */